@@ -64,6 +64,7 @@ import java.util.Set;
 import java.util.regex.Pattern;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
+import com.openexchange.groupware.contexts.Context;
 import com.openexchange.java.Streams;
 import com.openexchange.java.Strings;
 import com.openexchange.java.UnsynchronizedStringReader;
@@ -90,7 +91,6 @@ public class MicroformatSubscribeService extends AbstractSubscribeService {
     private SubscriptionSource source;
     private final List<ObjectParser> objectParsers = new LinkedList<ObjectParser>();
 
-
     /**
      * Initializes a new {@link MicroformatSubscribeService}.
      */
@@ -98,6 +98,36 @@ public class MicroformatSubscribeService extends AbstractSubscribeService {
         super();
     }
 
+    @Override
+    public boolean isCreateModifyEnabled() {
+        ConfigurationService configService = OXMFServiceRegistry.getInstance().getService(ConfigurationService.class);
+        return null != configService && configService.getBoolProperty("com.openexchange.subscribe.microformats.createModifyEnabled", false);
+    }
+
+    @Override
+    public void subscribe(Subscription subscription) throws OXException {
+        if (false == isCreateModifyEnabled()) {
+            throw OXMFSubscriptionErrorMessage.FORBIDDEN_CREATE_MODIFY.create();
+        }
+        super.subscribe(subscription);
+    }
+
+    @Override
+    public void touch(Context ctx, int subscriptionId) throws OXException {
+        if (false == isCreateModifyEnabled()) {
+            throw OXMFSubscriptionErrorMessage.FORBIDDEN_CREATE_MODIFY.create();
+        }
+        super.touch(ctx, subscriptionId);
+    }
+
+    @Override
+    public void update(final Subscription subscription) throws OXException {
+        if (false == isCreateModifyEnabled()) {
+            throw OXMFSubscriptionErrorMessage.FORBIDDEN_CREATE_MODIFY.create();
+        }
+        super.update(subscription);
+    }
+
     @Override
     public boolean checkForDuplicate() {
         return true;
@@ -168,7 +198,7 @@ public class MicroformatSubscribeService extends AbstractSubscribeService {
 
     @Override
     public boolean handles(int folderModule) {
-        return source.getFolderModule() == folderModule;
+        return (source.getFolderModule() == folderModule) && isCreateModifyEnabled();
     }
 
     /**
